@@ -1,5 +1,5 @@
 # The SGE Specification
-# Written in 2012, 2013 by Julian Marchant <onpon4@riseup.net> 
+# Written in 2012, 2013, 2014 by Julian Marchant <onpon4@riseup.net> 
 # 
 # To the extent possible under law, the author(s) have dedicated all
 # copyright and related and neighboring rights to this software to the
@@ -118,6 +118,10 @@ class Font(object):
         """
         # TODO
 
+    def destroy(self):
+        """Destroy the font."""
+        # TODO
+
     @classmethod
     def from_sprite(cls, sprite, chars, ID=None, hsep=0, vsep=0, size=12,
                     underline=False, bold=False, italic=False):
